@@ -23,6 +23,7 @@
 #  define __components_connection_h__
 
 #include <libgda/gda-connection.h>
+#include <gtk/gtkwidget.h>
 
 G_BEGIN_DECLS
 
@@ -34,6 +35,7 @@ GdaConnection     *components_connection_open (const gchar *name,
 GdaConnection     *components_connection_open_dialog (GtkWidget *parent,
 						      gchar **selected_name);
 void               components_connection_close (GdaConnection *cnc);
+void               components_connection_close_all (void);
 
 G_END_DECLS
 
